@@ -854,7 +854,7 @@ class ESN:
         repr += "noise level inside activation function = " + "{0:.2e}\n".format(self.noiseLevel_in)
         repr += "noise level outside activation function = " + "{0:.2e}\n".format(self.noiseLevel_out)
 
-        repr += "transientTime = " + {0}.format(self.transientTime)
+        repr += "transientTime = " + "{0}".format(self.transientTime)
         
         return repr
 
